@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from r3sponse.classes import *
+from Response.classes import *
 
 # source path & version.
 from fil3s import Version, Directory, Files, gfp
