@@ -8,6 +8,9 @@ import traceback as _traceback_
 # inc imports.
 from fil3s import *
 
+# DEPRICATED.
+Response.log("&RED&DEPRICATED&ORANGE&: Package r3sponse has moved to package fil3s.&END& Import as 'from fil3s import *' & replace 'Response' to 'Response'.")
+
 # functions.
 def __get_operating_system__():
 	os = platform.system().lower()
