@@ -2,10 +2,10 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from r3sponse.classes.config import *
-from r3sponse.classes import utils
-from r3sponse.classes.utils import color, symbol
-from r3sponse.classes import exceptions
+from Response.classes.config import *
+from Response.classes import utils
+from Response.classes.utils import color, symbol
+from Response.classes import exceptions
 from django.http import JsonResponse
 import json as pypi_json
 import traceback as _traceback_
@@ -152,7 +152,7 @@ class R3sponse(object):
 			comparison = log_level != None and log_level >= required_log_level
 		except TypeError as e:
 			if "not supported between instances of 'dict' and 'int'" in f"{e}":
-				raise TypeError(f"You most likely returned a r3sponse.error_response when you meant a r3sponse.success_response, error: {e}")
+				raise TypeError(f"You most likely returned a Response.error_response when you meant a Response.success_response, error: {e}")
 			else:
 				raise TypeError(e)
 		if comparison:
@@ -217,7 +217,7 @@ class R3sponse(object):
 			#	#print(f"Serialized generator output instance: [{response.__class__.__name__}].")
 			#	#return response
 			#except Eception as e:
-			#	return r3sponse.error(f"An error occured during the execution of generator [{response}], error: {e}")
+			#	return Response.error(f"An error occured during the execution of generator [{response}], error: {e}")
 
 		# check ResponseObject.
 		elif response.__class__.__name__ in ["ResponseObject"]:
@@ -326,12 +326,12 @@ class Parameters(object):
 		traceback=None,
 	):
 		if request == None:
-			raise exceptions.InvalidUsage("<r3sponse.paramters.get>: Define parameter: [request].")
+			raise exceptions.InvalidUsage("<Response.paramters.get>: Define parameter: [request].")
 		
 		# single parameter.
 		if isinstance(parameters, (str,String)):
 			parameters = str(parameters)
-			response = r3sponse.response()
+			response = Response.response()
 			format = None
 			if ":" in parameters:
 				parameters,format = parameters.split(":")
@@ -344,9 +344,9 @@ class Parameters(object):
 				variable = request.GET.get(parameters)
 			if variable in ["", None]:
 				if traceback != None:
-					return variable, r3sponse.error(f"{traceback}: Define parameter: [{parameters}].")
+					return variable, Response.error(f"{traceback}: Define parameter: [{parameters}].")
 				else:
-					return variable, r3sponse.error(f"Define parameter: [{parameters}].")
+					return variable, Response.error(f"Define parameter: [{parameters}].")
 			elif format != None:
 				if format in ["str", "string"]: variable = str(variable)
 				elif format in ["int", "integer"]: variable = int(variable)
@@ -356,10 +356,10 @@ class Parameters(object):
 				elif format in ["float", "double"]: variable = float(variable)
 				elif format in ["array", "list"]: variable = variable.split(",")
 				else:
-					raise ValueError(f"Unrecognized <r3sponse.parameters.get> format: {format}.")
+					raise ValueError(f"Unrecognized <Response.parameters.get> format: {format}.")
 			
 			# handler.
-			return variable, r3sponse.success(f"Succesfully retrieved request parameter [{parameters}].", {
+			return variable, Response.success(f"Succesfully retrieved request parameter [{parameters}].", {
 				"key":parameters,
 				"value":variable,
 			})
@@ -382,7 +382,7 @@ class Parameters(object):
 				for key in parameters:
 					try: params[key]
 					except: params[key] = default
-			return params, r3sponse.success(f"Succesfully retrieved {len(params)} request parameter(s).")
+			return params, Response.success(f"Succesfully retrieved {len(params)} request parameter(s).")
 
 		# dict recursive.
 		elif isinstance(parameters, (dict, Dictionary, ResponseObject)):
@@ -403,7 +403,7 @@ class Parameters(object):
 				for key,default in parameters.items():
 					try: params[key]
 					except: params[key] = default
-			return params, r3sponse.success(f"Succesfully retrieved {len(params)} request parameter(s).")
+			return params, Response.success(f"Succesfully retrieved {len(params)} request parameter(s).")
 
 
 		# invalid.
@@ -427,9 +427,9 @@ class Parameters(object):
 			name,parameter = parameters
 			if parameter == default: 
 				if traceback != None:
-					return r3sponse.error(f"{traceback}: Define parameter [{name}].")
+					return Response.error(f"{traceback}: Define parameter [{name}].")
 				else:
-					return r3sponse.error(f"Define parameter [{name}].")
+					return Response.error(f"Define parameter [{name}].")
 			if ":" in name:
 				name,formats = name.split(":")
 				while True:
@@ -438,15 +438,15 @@ class Parameters(object):
 				formats = formats.split(",")
 				param_format = Formats.get(parameter, serialize=True)
 				if param_format not in formats:
-					return r3sponse.error(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Array(path=False, array=formats).string(joiner=', ')}.")
-			return r3sponse.success(f"Succesfully checked parameter [{name}].")
+					return Response.error(f"Incorrect parameter [{name}:{param_format}] format, correct format(s): {Array(path=False, array=formats).string(joiner=', ')}.")
+			return Response.success(f"Succesfully checked parameter [{name}].")
 
 		# recursive.
 		elif isinstance(parameters, (dict,Dictionary,ResponseObject)):
 			for id, value in parameters.items():
 				response = self.check(parameters=(id, value), default=default, traceback=traceback)
 				if response["error"] != None: return response
-			return r3sponse.success(f"Succesfully checked {len(parameters)} parameter(s).")
+			return Response.success(f"Succesfully checked {len(parameters)} parameter(s).")
 		# invalid.
 		else: 
 			raise exceptions.InstanceError(f"Parameter [parameters] requires to be a [dict, Dictionary, tuple] not [{parameters.__class__.__name__}].")
@@ -489,7 +489,7 @@ class ResponseObject(object):
 			elif isinstance(json, dict):
 				self.assign(json)
 			elif json != None:
-				raise exceptions.InvalidUsage("The r3sponse.ResponseObject json parameter must be str / dict format.")
+				raise exceptions.InvalidUsage("The Response.ResponseObject json parameter must be str / dict format.")
 		else:
 			self.assign(attributes)
 
@@ -519,10 +519,10 @@ class ResponseObject(object):
 			# check error passed as success response. & reversed
 			if self.message != None and len(self.message) >= len("Failed") and self.message[:len("Failed")] == "Failed":
 				#_traceback_.print_exc() 
-				raise ValueError("A success response may not start with (failed ...). You most likely called an r3sponse.success return while you meant r3sponse.error.")
+				raise ValueError("A success response may not start with (failed ...). You most likely called an Response.success return while you meant Response.error.")
 			if self.error != None and len(self.error) >= len("Success") and self.error[:len("Success")] == "Success":
 				#_traceback_.print_exc() 
-				raise ValueError("An error response may not start with (success ...). You most likely called an r3sponse.error return while you meant r3sponse.success.")
+				raise ValueError("An error response may not start with (success ...). You most likely called an Response.error return while you meant Response.success.")
 		
 		# except if not present.
 		except AttributeError: a=1
