@@ -2,7 +2,7 @@
 # -*- coding: utf-8 -*-
 
 # imports.
-from r3sponse.classes.config import * 
+from Response.classes.config import * 
 
 # argument functions.
 def argument_present(arguments):
